//+------------------------------------------------------------------+
//|                                                      MA_MACD.mq4 |
//|                                 Copyright  2006, Pierre Mouawad |
//|                                                                  |
//+------------------------------------------------------------------+
#property copyright "Copyright  2006, Pierre Mouawad"
#property link      ""

extern double Invest     = 10;  // %% to invest in each new trade out of the total account free margin -- zero to deactivate it
extern double EntryLevel = 10;
extern double Slippage   = 5;
extern double StopLoss   = 25;
extern double TrailStop  = 25;
extern double TakeProfit = 0;   // zero to deactivate it
extern double Lots       = 0.1; // min lots, if you have "Invest">0, then the total lots/trade will be calculated accordingly
extern double FastSMA    = 20;
extern double FastShift  = 0;
extern double SlowSMA    = 50;
extern double SlowShift  = 0;
extern double SpreadMin  = 5;  // zero to deactivate it
extern double SpreadMax  = 20; // zero to deactivate it

bool     BuySignal = false, SellSignal = false;
double   Lotsi;

//+------------------------------------------------------------------+
//| lots calculation                                                 |
//+------------------------------------------------------------------+
double Lotsi()
{
   double Lots = NormalizeDouble((AccountFreeMargin()/500)*(Invest/100),1);
   if (Lotsi<Lots)
      Lotsi=Lots;
   return(Lotsi);
}
//+------------------------------------------------------------------+
//| trading signal condition for long & short                        |
//+------------------------------------------------------------------+
void OpenLongShort()
   {
   double fsma=iMA(NULL,0,FastSMA,0,MODE_SMA,PRICE_CLOSE,0);
   double fsma1=iMA(NULL,0,FastSMA,0,MODE_SMA,PRICE_CLOSE,1);
   double fsma2=iMA(NULL,0,FastSMA,0,MODE_SMA,PRICE_CLOSE,2);
   double ssma=iMA(NULL,0,SlowSMA,0,MODE_SMA,PRICE_CLOSE,0);
   double ssma1=iMA(NULL,0,SlowSMA,0,MODE_SMA,PRICE_CLOSE,1);
   double ssma2=iMA(NULL,0,SlowSMA,0,MODE_SMA,PRICE_CLOSE,2);
   double macd=iMACD(NULL,0,12,26,9,PRICE_CLOSE,MODE_MAIN,0);
   double macd1=iMACD(NULL,0,12,26,9,PRICE_CLOSE,MODE_MAIN,1);
   double macd2=iMACD(NULL,0,12,26,9,PRICE_CLOSE,MODE_MAIN,2);
   double Target;
   
   if (BuySignal == (Ask>fsma && fsma>ssma && fsma1>ssma1 && fsma>fsma1 && MathAbs(fsma-fsma1)>1*Point
                      && MathAbs(fsma-ssma)>1*Point && MathAbs(fsma-ssma)<5*Point && MathAbs(fsma-ssma)>MathAbs(fsma1-ssma1)
                      && MathAbs(Ask-fsma)<EntryLevel*Point && macd>macd1 && macd1>macd2))
   if (TakeProfit==0) Target=0;
   else Target=Ask+(TakeProfit*Point);
         OrderSend(Symbol(),OP_BUY,Lotsi(),Ask,Slippage,fsma-(StopLoss*Point),Target,"LONG Position Initiated",0,0,Green);
   
   if (SellSignal == (Bid<fsma && fsma<ssma && fsma1<ssma1 && fsma<fsma1 && MathAbs(fsma-fsma1)>1*Point
                        && MathAbs(fsma-ssma)>1*Point && MathAbs(fsma-ssma)<5*Point && MathAbs(fsma-ssma)>MathAbs(fsma1-ssma1)
                        && MathAbs(Bid-fsma)<EntryLevel*Point && macd<macd1 && macd1<macd2))
   if (TakeProfit==0) Target=0;
   else Target=Bid-(TakeProfit*Point);
         OrderSend(Symbol(),OP_SELL,Lotsi(),Bid,Slippage,fsma+(StopLoss*Point),Target,"Short Position Initiated",0,0,Red);
   }
//+------------------------------------------------------------------+
//| open orders management                                           |
//+------------------------------------------------------------------+
void OrderManagement()
   {

   int total = OrdersTotal();
   
   for(int cnt=0; cnt<total; cnt++)
   {
   OrderSelect(cnt, SELECT_BY_POS);            
   if(OrderSymbol() == Symbol() && OrderType()==OP_BUY) // long order management
      {
       if (Bid-(TrailStop*Point)<OrderOpenPrice())
             OrderModify(OrderTicket(),OrderOpenPrice(),Bid-(TrailStop*Point),OrderTakeProfit(),0,LightGreen);
		}
   if(OrderSymbol() == Symbol() && OrderType()==OP_SELL) // short order management
      {
       if (Ask+(TrailStop*Point)>OrderOpenPrice())
             OrderModify(OrderTicket(),OrderOpenPrice(),Ask+(TrailStop*Point),OrderTakeProfit(),0,LightGreen);
      }
   }   
   }
//+------------------------------------------------------------------+
//| EA start function                                                |
//+------------------------------------------------------------------+
int start()
   {
   if(Bars<100 || IsTradeAllowed()==false) return(0);

// a minimum risk to reward ratio of 1:1
   if(TakeProfit<StopLoss)
     {
      Comment("TakeProfit should be at least equal to StopLoss");
      return(0);
     }
   OpenLongShort();
   OrderManagement();
   }
//+------------------------------------------------------------------+